/* ************************************************************************ */
/* FUNCTIONAL DESCRIPTION:                                                  */
/* This command file performs looping Sync on the C and A drives            */
/*                                                                          */
/* USAGE CONSTRAINTS: None.                                                 */
/*                                                                          */
/* MODIFICATION HISTORY:                                                    */
/*                                                                          */
/* DATE         BY              MODIFICATION                                */
/* --------------------------------------------------------------------     */
/* 10/14/91     A. Patel        Original                                    */
/*                                                                          */
/*                                                                          */
/* PARAMETERS:                                                              */
/*      INPUTS:                                                             */
/*      OUTPUTS:                                                            */
/*                                                                          */
/* ************************************************************************ */
/* Error Constants :  1 = Unable to make directory                          */
/*                    2 = Unable to delete directory                        */
/*                    3 = Test 1 Failure                                    */
/*                    4 = Test 2 Failure                                    */
/*                    5 = Unable to delete files in Test 3                  */
/*                    6 = Test 3 Failure                                    */
/*                    7 = Unable to cleanup directory at end of iteration   */
/*                                                                          */
/* ************************************************************************ */
/* Main Routine */

    say ""
    say "CRUISER Sync Exerciser  starting"
    say ""

/* Make call to SysLoadFuncs so that all REXX objects can be accessed  */

    call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
    call SysLoadFuncs
    call SysCls

    i=0
    do forever

    i=i+1
    say "Iteration: " i

     /* Make Parttest directory if it doesn't exist */

     call sysFileTree '\parttest', 'file', 'D'

     if file.0 = 0 then

         "mkdir \parttest"

     /* Make Syncx directory if it doesn't exist */

     call sysFileTree '\parttest\syncx', 'file', 'D'

     if file.0 = 0 then

        /* "mkdir \parttest" */
         "mkdir \parttest\syncx"

         /* Test 1 sync data\syncx with \parttest\syncx, recursively processing
            subdirectories
         */

         say "Test 1 - Syncing  \data\syncx with \parttest\syncx"
         '\aps\unx\sync -r -v -t \data\syncx \parttest\syncx'
         if rc > 0
         then
              call quit 3, i
         else
              say "Test 1 ran successfully"


         /* Test 2 Perform sync data\syncx with \parttest\syncx again - files match
         */

         say "Test 2 - syncing \data\syncx with partest\syncx again - files match"
         '\aps\unx\sync -r -v -t \data\syncx \parttest\syncx'
         if rc > 0
         then
              call quit 4, i

          /* Test 3 delete file from \partest\syncx\syncdir and re-sync */

          say "Test 3 delete sync file from and re-sync"
          'del \parttest\syncx\syncdir\syncf1.txt'

          if rc > 0 then
               call quit 5, i

          '\aps\unx\sync -r -v -t \data\syncx \parttest\syncx'

          if rc > 0 then
                call quit 6, i

          /* All done, delete files and directories */


          'del \parttest\syncx\syncdir\*.txt'

          if rc > 0 then
                call quit 7, i

          'del \parttest\syncx\*.txt'

          if rc > 0 then
                call quit 7, i

          'rd \parttest\syncx\syncdir'
          if rc > 0
          then
                call quit 2, i

          'rd \parttest\syncx'
          if rc > 0
          then
                call quit 2, i
       end  /* do */

/* Quit Procedure */

    quit:
    select
        when arg(1) = 1 then
            say "Unable to make directory...Quitting in iteration " arg(2)

        when arg(1) = 2 then
            say "Unable to remove directory...Quitting in iteration " arg(2)

        when arg(1) = 3 then
            say "Test 1 failed...Quitting in iteration " arg(2)

        when arg(1) = 4 then
            say "Test 2 failed...Quitting in iteration " arg(2)

        when arg(1) = 5 then
            say "Unable to delete files in Test 3...Quitting in iteration " arg(2)

        when arg(1) = 6 then
            say "Test 3 failed...Quitting in iteration " arg(2)

        when arg(1) = 7 then
            say "Unable to delete files at end of iteration...Quitting in iteration " arg(2)
    end
    exit
