/*----------------------------------------------------------------------*/
/* RUNMME.CMD - REXX command file to execute SVT test scripts           */
/*                                                                      */
/* Brian Beery  5/25/93 adapted from Buckets/Runscen.cmd                */
/* swhudson    11/28/93 modified for PCM Testkit for standalone w/o LAN */
/*                                                                      */
/* syntax: RUN                         ( runs all buckets )             */
/*         RUN bktname [start] [end]   ( runs a selected bucket )       */
/*                                                                      */
/* [start] and [end] are optional, and indicate the starting and ending */
/* tests within the bucket.                                             */
/*----------------------------------------------------------------------*/
'@echo off'
'cls'
say ''

os2drv = value('PCM_BOOTDRV',,'OS2ENVIRONMENT');       /* get OS2 boot drive */
tstdrv = value('PCM_TESTDRV',,'OS2ENVIRONMENT');       /* get testcase drive */
if pos(os2drv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ************************************************************[0;40;37m'
   say '[1;09;41m * Environment variable PCM_BOOTDRV not set.  Run PCMSETUP  *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.*[0;40;37m'
   say '[1;09;41m ************************************************************[0;40;37m'
   exit
   end
if pos(tstdrv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '[1;09;41m ************************************************************[0;40;37m'
   say '[1;09;41m * Environment variable PCM_TESTDRV not set.  Run PCMSETUP  *[0;40;37m'
   say '[1;09;41m * to update config.sys, then shutdown & reboot to continue.*[0;40;37m'
   say '[1;09;41m ************************************************************[0;40;37m'
   exit
   end


tstdrv':'
'cd \build\src\svt\buckcmd'


Call RxFuncAdd "SysFileTree","RexxUtil","SysFileTree"

'Call \util\config.cmd'


Parse Arg BucketName Start End  /* get arguments */

/* ----------------------------------get environment variables */
DutId=VALUE("MME-DUTID",,"OS2ENVIRONMENT")
Build=VALUE("MME-BUILDVER",,"OS2ENVIRONMENT")

/* ------------------------------------------------------- */
/* Check for bucket name. if ? or blank signal info_please */
/* ------------------------------------------------------- */

If (BucketName="")  then signal INFO_PLEASE
If (BucketName="?") then signal INFO_PLEASE
Else do
     ClearBucket = BucketName;
     BucketName=BucketName'.tst'
     end

/*------------------------------*/
/* find matching the BucketName */
/*------------------------------*/
Junk=SysFileTree(Bucketname,TestFiles,"OF")

if TestFiles.0=0 then Do
   SAY 'No tests found matching 'Bucketname'!!!'
   exit
   End

/* ------------------------------------------------ */
/* Bucketname verified - Clear old logs before run  */
/* ------------------------------------------------ */
'erase 'tstdrv':\results\mmepcm\svtraw\'ClearBucket'.*'
'erase 'tstdrv':\results\mmepcm\svtlog\'ClearBucket'.*'
'erase 'tstdrv':\results\mmepcm\svtres\*.res'

'erase 'tstdrv':\dutpcm\mmepcm\* <'tstdrv':\util\yes.in'

/* ---------------------------------------------- */
do ListCtr=1 to TestFiles.0

   MaxTests=ReadTestList(ListCtr)

   if (Start="") then Start=1
   if (End="")   then End=MaxTests

   if (Start>MaxTests) then do
      Parse value BucketName with Fname "." FExt
      Call LogResults Fname
      exit
      end

   if ((End<Start)|(End>MaxTests)) then Call Syntax

   Say "Starting "TestFiles.ListCtr
   Say "-----------------------------------------------------------------------------"
   Say 'Setting up Environment...'
   /*---------------------------*/
   /* set environment variables */
   /*---------------------------*/
'  @Call setenv'
   /* ----------------------*/
   /* clear out old results */
   /* ----------------------*/
'  del \%MME-DUTID%\MME%MME-BUILDVER%\MME%MME-BUILDVER%.*'
'  del \%MME-DUTID%\MME%MME-BUILDVER%\logfile 1>nul 2>nul'

   ClearOutLogs=Value("LOGKILL","","OS2ENVIRONMENT")
   if ClearOutLogs<>'NO' then do
      Say 'Clearing out old logfiles...'
'     call clearlog 'BucketName' 1>nul 2>nul'
'     del \%MME-DUTID%\MME%MME-BUILDVER%\logfile 1>nul 2>nul'
      end

   do ctr=Start to Min(MaxTests,End)   /* run all of the tests in the bucket */
      Call RunTest ctr
   end /* enddo - ctr */

   Start=''                                /* clear the start and end values */
   End=''
   /* ------------------------------------------------------------*/
   /* do a COPYRES to log results to the appropriate directories. */
   /* ------------------------------------------------------------*/
   Say TestFiles.ListCtr
   Parse value FileSpec("name",TestFiles.ListCtr) with Fname "." FExt
   Call LogResults Fname

end  /* enddo loop - listctr */
exit /* done!                */



/* ------------------------------------------------------------------------- */
Runtest: Procedure Expose Build DutId ListCtr BucketName TestName. Scen. TestFiles.

/* runs a single test within the given bucket */

Parse Arg WhichTest
Parse Value BucketName With BucketFile '.' Junk
NextTest=WhichTest+1

/* remove temporary files */
'        rm -f %TESTDATA%\*'
/* return MMPM2.INI to its default state */
'        Call ResetIni'
/*------------------------------------------*/
/* Determine where to look for test script: */
/* Use first letter of file extension...    */
/*------------------------------------------*/
Parse Upper Value TestName.WhichTest with Filename '.' Extension
ToolCode=LEFT(Extension,1)
Fluff=LEFT(Scen.WhichTest,1)

select
      /*------------*/
      /* P=P2STRING */
      /*------------*/
      when ToolCode='P' then do
           ScriptPath='\build\src\svt\scripts\'
           ToolName='P2STRING'
           end
      /*------------*/
      /* M=MCITL    */
      /*------------*/
      when ToolCode='M' then do
           ScriptPath='\build\src\svt\scripts\'
           ToolName='MCITL'
           end
      /*-------------------------------------*/
      /* C=MISCELLANEOUS, run from .CMD file */
      /*-------------------------------------*/
      when ToolCode='C' then do
           ScriptPath='\build\src\svt\cmd\'
           ToolName='a .cmd file'
           end

      when Fluff='G' then do
           ScriptPath='\build\src\mdm\procedur\group\'
           ToolName='MCITL'
           /*------------------------*/
           /* decode group test name */
           /*------------------------*/
           GroupTest="GP"||SUBSTR(FileName,6,1)||SUBSTR(Extension,1,3)"."Scen.WhichTest
           end
      otherwise
           SAY "ERROR--I don't know what to do with "Filename"."Extension
           exit
end /* select */

Say 'Executing 'BucketName' Test Case #'WhichTest': 'TestName.WhichTest' using 'ToolName' (Fluff='Fluff')'




























/* check for proper cds in cd-roms */

'    call cdd2 %MME-TESTDRIVE%:'||ScriptPath||TestName.WhichTest

/*--------------------------------------*/
/* run the actual test, 1st             */
/* check to see if the .IND file exists */
/*--------------------------------------*/
rcode=Stream('\'DutId'\MME'Build'\MME'Build'.IND',"c","query exists")

if (rcode<>"") then do              /* file already there, close it back up! */
   Junk=Stream('\'DutId'\MME'Build'\MME'Build'.IND',"c","close")
   End
else                               /* does not exist, do some initialization */
   Do
      CDSVT=VALUE("CDSVT",,"OS2ENVIRONMENT")
      if (CDSVT='') then
'        echo 000000000,%mme-dutid% > \%mme-dutid%\mme%mme-buildver%\mme%mme-buildver%.ind'
      else
'     echo 000000000,%mme-dutid%,'CDSVT' > \%mme-dutid%\mme%mme-buildver%\mme%mme-buildver%.ind'
   End
   if (Fluff="G") then
'     echo #SCEN,'GroupTest',1,START >> \%mme-dutid%\mme%mme-buildver%\mme%mme-buildver%.ind'
   else
'     echo #SCEN,'Filename'.'Scen.WhichTest',1,START >> \%mme-dutid%\mme%mme-buildver%\mme%mme-buildver%.ind'
/*-----------------------------------------*/
/* call the test tool (or the test itself) */
/*-----------------------------------------*/

select
when ToolCode="P" then Do
'    start "SVT-TEST 'TestName.WhichTest' 1" %svtpath%cmd\p2string 'ScriptPath||TestName.WhichTest' -a\%MME-DUTID%\MME%MME-BUILDVER%\logfile -d '
     end

when ToolCode="M" then do
'    start "SVT-TEST 'TestName.WhichTest' 1" %svtpath%cmd\mcitl -k -e \%MME-DUTID%\MME%MME-BUILDVER%\logfile' ScriptPath||TestName.WhichTest
     end

when ToolCode="C" then do
'    start /f /c "SVT-TEST 'TestName.WhichTest' 1" %svtpath%cmd\'TestName.WhichTest
     end

when Fluff="G" then do
'    start "SVT-TEST 'GroupTest' 1" %svtpath%cmd\mcitl -k -e \%MME-DUTID%\MME%MME-BUILDVER%\logfile' ScriptPath||TestName.WhichTest
     end

otherwise:
     SAY "Sorry, I do not know what to do with "TestName.WhichTest
     exit
end /* select */

/*-------------------------*/
/* wait for test to finish */
/*-------------------------*/
do until (rc=0)
'  %SVTPATH%TOOLS\sleep 10'
'  %SVTPATH%TOOLS\killname /l SVT-TEST* >nul'
end /* do */








/*-----------------------------------*/
/* log end of scenario to index file */
/*-----------------------------------*/
   if (Fluff="G") then
'     echo #SCEN,'GroupTest',1,1,END >> \%mme-dutid%\mme%mme-buildver%\mme%mme-buildver%.ind'
   else
'     echo #SCEN,'Filename'.'Scen.WhichTest',1,1,END >> \%mme-dutid%\mme%mme-buildver%\mme%mme-buildver%.ind'
/*---------------------------------------------*/
/* done with test, return to calling procedure */
/*---------------------------------------------*/
return 0



LogResults: Procedure
Parse Arg BucketName
'Call \util\beep'
Say 'Doing a COPYRES on 'BucketName' - Results will be under \RESULTS\MMEPCM'
'%SVTPATH%TOOLS\sleep 30'
'call copyres' BucketName
'call resetini'
return 0



Syntax:
Say 'Syntax for RUN.CMD: RUN [Bucket#[ Start[,End]]]'
Say 'Bucket#: The name of the bucket to run'
Say 'Start: The number of the first test to run'
Say 'End: The number of the last test to run'
exit


ReadTestList: Procedure Expose testcount TestFiles. TestName. Scen.
/*--------------------------*/
/* reads in a single bucket */
/*--------------------------*/
Parse Arg Which

testcount=0
do while LINES(TestFiles.Which)<>0
   testcount=testcount+1
   Buffer=LINEIN(TestFiles.Which,,1)
   Parse Value Buffer With TestName.testcount Scen.testcount
   if Scen.testcount='' then /* no Scen specified, defaults to 0 */
      Scen.testcount=0
end /* do */

if (testcount=0) then do                 /* file not found or cannot be read */
   Say 'Error-Cannot read 'TestFiles.Which
   exit
   end
else                                     /* read the file ok */
   Junk=Stream(TestFiles.Which,"c","close")

return testcount


exit
INFO_PLEASE:
say ''
say '[1;26;45m  ͻ'
say ' RUNMME.CMD - Runs Multimedia testcase buckets in PCM testkit.    '
say '                                                                  '
say ' Parameters: (REQUIRED) BUCKET Name (without .tst extension)      '
say '                                                                  '
say '             (Optional) FIRST#  start with test # in bucket       '
say '             (Optional) LAST#   stop after test # in bucket       '
say '                                                                  '
say ' Examples: runmme pcmsvga     (SVGA 1024x768x256 resoulution)     '
say '           runmme pcmvga      (VGA resolution)                    '
say '           runmme pcmvga 3 8  (run tests 3 -> 8 in pcmvga bucket) '
say '                                                                  '
say ' Uses OS/2 environment variables to determine testcase drive.     '
say 'ͼ[0;40;37m'
exit
